# YARRtist

YARRtist is a plotting tool based on `matplotlib` for plotting summaries of YARR
scan or configuration file for ITk modules.

More documentation for installation and plots can be found in `docs` .
